==> ui-list-10.15.2.tgz: package/es/List/ListItem/__new-tests__/ListItem.test.js <==
var _ListItem;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

import React from 'react';
import '@testing-library/jest-dom';
import { render, screen } from '@testing-library/react';
import { vi } from 'vitest';
import { ListItem } from '../index';
describe('<ListItem />', () => {
  it('should render children', async () => {
    render(_ListItem || (_ListItem = /*#__PURE__*/React.createElement(ListItem, null, "hello")));
    const listItem = screen.getByRole('listitem');
    expect(listItem).toHaveTextContent('hello');
  });
  it('should call elementRef', async () => {
    const elementRef = vi.fn();
    render(/*#__PURE__*/React.createElement(ListItem, {
      elementRef: elementRef
    }, "List item"));
    const listItem = screen.getByRole('listitem');
    expect(elementRef).toHaveBeenCalledWith(listItem);
  });
});

==> ui-list-10.19.1.tgz: package/es/List/ListItem/__new-tests__/ListItem.test.js <==
var _ListItem;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

import '@testing-library/jest-dom';
import { render, screen } from '@testing-library/react';
import { vi } from 'vitest';
import { ListItem } from '../index';
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
describe('<ListItem />', () => {
  it('should render children', async () => {
    render(_ListItem || (_ListItem = _jsx(ListItem, {
      children: "hello"
    })));
    const listItem = screen.getByRole('listitem');
    expect(listItem).toHaveTextContent('hello');
  });
  it('should call elementRef', async () => {
    const elementRef = vi.fn();
    render(_jsx(ListItem, {
      elementRef: elementRef,
      children: "List item"
    }));
    const listItem = screen.getByRole('listitem');
    expect(elementRef).toHaveBeenCalledWith(listItem);
  });
});
